Small bug-fix and mark deprecated.

- Changelog is https://github.com/attakei/sphinx-revealjs/blob/v3.0.2/CHANGELOG.rst
- Source changes is https://github.com/attakei/sphinx-revealjs/compare/v3.0.1...v3.0.2
